@@ -168,6 +168,7 @@ analysisOrganizeData <- function(df, analySpec=list(), reports=c(0,1,2,3)
 
 # df<-dataCensored; analySpec<-list(); parameterList<-stationMasterList<-layerLukup<-reports<-NA
 # ----- Change history --------------------------------------------
+# 28Dec2018: JBH: add default seasonal mean of July 1-Sept 30 to gamLegend
 # 01May2018: JBH: removed median as option for layer aggregation  
 # 06Aug2017: JBH: added gamFlw_Sal.Wgt.Perc
 # 05Aug2017: JBH: cleaned up change history date formats
@@ -229,31 +230,9 @@ analysisOrganizeData <- function(df, analySpec=list(), reports=c(0,1,2,3)
   if (!"gamAlpha"        %in% names(analySpec)) analySpec$gamAlpha         <- c(0.05)
   if (!"censorTrim"      %in% names(analySpec)) analySpec$censorTrim       <- c(0.5,0.40)  #01Nov2016
 
-  if (!"gamModels"      %in% names(analySpec)) analySpec$gamModels       <- list(  #21Jul2017
-    list(option=0, name= "Linear Trend with Seasonality",
-         model= "~ cyear + s(doy,bs='cc')", 
-         deriv=TRUE, gamK1=c(NA,NA), gamK2=c(NA,NA)),
-    list(option=1, name= "Non-linear Trend with Seasonality",
-         model= "~ cyear + s(cyear, k=gamK1) + s(doy,bs='cc')", 
-         deriv=TRUE, gamK1=c(10,2/3), gamK2=c(NA,NA)),
-    list(option=2, name= "Non-linear trend with Seas+Int",
-         model= "~ cyear + s(cyear, k=gamK1) + s(doy,bs='cc')+ ti(cyear,doy,bs=c('tp','cc'))", 
-         deriv=TRUE, gamK1=c(10,2/3), gamK2=c(NA,NA)),
-    list(option=3, name= "Non-linear trend with Seas+Int. & Intervention",
-         model= "~ intervention + cyear + s(cyear, k=gamK1) + s(doy,bs='cc') + ti(cyear,doy,bs=c('tp','cc'))", 
-         deriv=TRUE, gamK1=c(10,2/3), gamK2=c(NA,NA)),  
-    list(option=4, name= "Non-linear trend with Seas+Int. & Hydro Adj",
-         model= paste0("~ cyear + s(cyear, k=gamK1) + s(doy,bs='cc') + ti(cyear,doy,bs=c('tp','cc')) + ",
-                       "s(flw_sal,k=gamK2) + ti(flw_sal,doy,bs=c('tp','cc')) + ti(flw_sal, cyear,bs=c('tp' ,'tp')) + ",
-                       "ti(flw_sal,doy,cyear, bs=c('tp','cc','tp'))"),
-         deriv=TRUE, gamK1=c(10,1/3), gamK2=c(10,2/3)))
-
-  # gam model with intervention and hydrologic adjustment -- could append to above list if desired in future version
-  # list(option=5, name= "Non-linear trend with Seas+Int. & Inter/Hydro Adj",
-  #      model= paste0("~ intervention + cyear + s(cyear, k=gamK1) + s(doy,bs='cc') + ti(cyear,doy,bs=c('tp','cc')) + ",
-  #                    "s(flw_sal,k=gamK2) + ti(flw_sal,doy,bs=c('tp','cc')) + ti(flw_sal, cyear,bs=c('tp' ,'tp')) + ",
-  #                    "ti(flw_sal,doy,cyear, bs=c('tp','cc','tp'))"),
-  #      deriv=TRUE, gamK1=c(10,1/3), gamK2=c(10,2/3))
+  # load gam0-gam4 if not specified #31Jul2018
+  if (!"gamModels"      %in% names(analySpec)) analySpec$gamModels       <- loadModels(c('gam0', 'gam1', 'gam2', 'gam3', 'gam4' ))
+  
 
   if (!"gamDiffPeriods"  %in% names(analySpec)) analySpec$gamDiffPeriods   <- list(
     list( periodName = "Full Record",     periodStart = c(NA),        periodEnd = c(NA)),
@@ -350,6 +329,19 @@ analysisOrganizeData <- function(df, analySpec=list(), reports=c(0,1,2,3)
 
   # add gamPlot legend  #01Nov2016
   analySpec$gamLegend <- gamLegend
+
+  # add default seasonal mean of July 1-Sept 30 #28Dec2018
+  analySpec$gamLegend <- rbind(analySpec$gamLegend, 
+                               data.frame(legend = '7/1-7/31'
+                                          , colSel        = 'red'     
+                                          , colLegend     = 'red'
+                                          , lwdLegend     = 1
+                                          , ltyLegend     = 1
+                                          , pchLegend     = NA
+                                          , fillLegend    = NA
+                                          , borderLegend  = NA
+                                          , season        = FALSE
+                                          , descrip       = 'seasMean'))
   
   # add newly created variables back to analySpec
   analySpec$idVar         <- idVar
